"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Wordpress = void 0;
const pulumi = require("@pulumi/pulumi");
const components_1 = require("./components");
const envPrefix = {
    bedrock: '',
    wordpress: 'WORDPRESS_',
};
class Wordpress extends pulumi.ComponentResource {
    constructor(name, args, opts = {}) {
        super('wordpress', name, args, opts);
        const { domain, build = '../site', location, databaseDiskSize, enableBackups, preset = 'bedrock', } = args;
        this.apiServices = new components_1.ApiServices(name, {}, { parent: this });
        this.gcrDocker = new components_1.GCRDocker(name, {
            build,
        }, { parent: this, dependsOn: this.apiServices });
        this.database = new components_1.MySQLComponent(name, {
            enableBackups,
            diskSize: databaseDiskSize,
        }, { parent: this, dependsOn: this.apiServices });
        this.service = new components_1.CloudRun(name, {
            image: this.gcrDocker.image.imageName,
            location,
            domain,
            dbEnvironmentPrefix: envPrefix[preset],
            databaseSettings: {
                connectionName: this.database.instance.connectionName,
                databaseName: this.database.database.name,
                databaseUsername: this.database.user.name,
                databasePassword: this.database.user.password,
            },
            envs: [
                {
                    name: 'WP_HOME',
                    value: pulumi.interpolate `https://${domain}/`,
                },
                {
                    name: 'WP_SITEURL',
                    value: pulumi.interpolate `https://${domain}/wp`,
                },
            ],
        }, { parent: this, dependsOn: this.apiServices });
    }
}
exports.Wordpress = Wordpress;
